@@ -59,7 +59,7 @@ class NRE(nn.Module):
         x_dim: The dimensionality :math:`L` of the observation space.
         moments: The parameters moments :math:`\mu` and :math:`\sigma`. If provided,
             the moments are used to standardize the parameters.
-        build: The network constructor (e.g. :class:`nn.MLP` or :class:`nn.ResMLP`).
+        build: The network constructor (e.g. :class:`lampe.nn.ResMLP`).
         kwargs: Keyword arguments passed to the constructor.
     """
 
@@ -139,6 +139,63 @@ class NRELoss(nn.Module):
         return l1 + l0
 
 
+class BNRELoss(nn.Module):
+    r"""Creates a module that calculates the loss :math:`l` of a balanced NRE (BNRE)
+    classifier :math:`d_\phi`. Given a batch of :math:`N` pairs
+    :math:`\{ (\theta_i, x_i) \}`, the module returns
+
+    .. math::
+        \begin{align}
+            l & = \frac{1}{N} \sum_{i = 1}^N
+            \ell(d_\phi(\theta_i, x_i)) + \ell(1 - d_\phi(\theta_{i+1}, x_i)) \\
+              & + \lambda \left(1 - \frac{1}{N} \sum_{i = 1}^N
+                d_\phi(\theta_i, x_i) + d_\phi(\theta_{i+1}, x_i)
+            \right)^2
+        \end{align}
+
+    where :math:`\ell(p) = - \log p` is the negative log-likelihood.
+
+    References:
+        Towards Reliable Simulation-Based Inference with Balanced Neural Ratio Estimation
+        (Delaunoy et al., 2022)
+        https://arxiv.org/abs/2208.13624
+
+    Arguments:
+        estimator: A classifier network :math:`d_\phi(\theta, x)`.
+        lmbda: The weight :math:`\lambda` controlling the strength of the balancing
+            condition.
+    """
+
+    def __init__(self, estimator: nn.Module, lmbda: float = 100.0):
+        super().__init__()
+
+        self.estimator = estimator
+        self.lmbda = lmbda
+
+    def forward(self, theta: Tensor, x: Tensor) -> Tensor:
+        r"""
+        Arguments:
+            theta: The parameters :math:`\theta`, with shape :math:`(N, D)`.
+            x: The observation :math:`x`, with shape :math:`(N, L)`.
+
+        Returns:
+            The scalar loss :math:`l`.
+        """
+
+        theta_prime = torch.roll(theta, 1, dims=0)
+
+        log_r, log_r_prime = self.estimator(
+            torch.stack((theta, theta_prime)),
+            x,
+        )
+
+        l1 = -F.logsigmoid(log_r).mean()
+        l0 = -F.logsigmoid(-log_r_prime).mean()
+        lb = (torch.sigmoid(log_r) + torch.sigmoid(log_r_prime) - 1).mean().square()
+
+        return l1 + l0 + self.lmbda * lb
+
+
 class AMNRE(NRE):
     r"""Creates an arbitrary marginal neural ratio estimation (AMNRE) classifier
     network.
@@ -275,14 +332,14 @@ class NPE(nn.Module):
     techniques.
 
     References:
-        https://wikipedia.org/wiki/Kullback%E2%80%93Leibler_divergence
+        https://wikipedia.org/wiki/Kullback-Leibler_divergence
 
     Arguments:
         theta_dim: The dimensionality :math:`D` of the parameter space.
         x_dim: The dimensionality :math:`L` of the observation space.
         moments: The parameters moments :math:`\mu` and :math:`\sigma`. If provided,
             the moments are used to standardize the parameters.
-        build: The flow constructor (e.g. :class:`lampe.nn.flows.MAF`).
+        build: The flow constructor (e.g. :class:`lampe.nn.flows.NSF`).
         kwargs: Keyword arguments passed to the constructor.
     """
 
@@ -483,7 +540,7 @@ class MetropolisHastings(object):
     can be modified by sub-classing :class:`MetropolisHastings`.
 
     Wikipedia:
-        https://wikipedia.org/wiki/Metropolis%E2%80%93Hastings_algorithm
+        https://wikipedia.org/wiki/Metropolis-Hastings_algorithm
 
     Arguments:
         x_0: A batch of initial points :math:`x_0`, with shape :math:`(*, L)`.
